:mod:`API`
----------------------------

`extract_model` Python API
==========================


.. automodule:: extract_model.extract_model
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:
